import BootstrapIcons from 'bootstrap-icons/bootstrap-icons.svg';

//
var script = {
  name: 'BootstrapIcon',
  props: {
    icon: {
      type: String,
      required: true
    },
    variant: {
      type: String,
      validator: value => ['success', 'warning', 'danger', 'info', 'primary', 'secondary', 'dark', 'light'].indexOf(value) !== -1
    },
    size: {
      type: String,
      validator: value => ['sm', 'md', 'lg', '2x', '3x', '4x', '5x'].indexOf(value) !== -1
    },
    flipH: {
      type: Boolean
    },
    flipV: {
      type: Boolean
    },
    rotate: {
      type: [String, Number],
      validator: value => value >= -360 && value <= 360
    },
    animation: {
      type: String,
      validator: value => ['cylon', 'cylon-vertical', 'fade', 'spin', 'spin-reverse', 'spin-pulse', 'spin-reverse-pulse', 'throb'].indexOf(value) !== -1
    }
  },
  computed: {
    cssClasses() {
      const classes = [];
      if (this.variant) classes.push(`bi--variant-${this.variant}`);
      if (this.size) classes.push(`bi--size-${this.size}`);
      if (this.animation) classes.push(`bi--animation-${this.animation}`);
      return classes;
    },

    svgTransform() {
      if (!this.flipH && !this.flipV && !this.rotate) return '';
      let scale;
      let rotate;

      if (this.flipV && this.flipH) {
        scale = '-1 -1';
      } else if (this.flipH) {
        scale = '-1 1';
      } else if (this.flipV) {
        scale = '1 -1';
      }

      if (this.rotate) {
        rotate = this.rotate;
      }

      return (scale ? `scale(${scale})` : '') + (rotate ? `rotate(${rotate})` : '');
    },

    svgSprite() {
      return BootstrapIcons;
    }

  },
  methods: {
    upperFirst(str) {
      if (typeof str !== 'string') return str;
      return str.charAt(0).toUpperCase() + str.slice(1);
    }

  }
};

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

const isOldIE = typeof navigator !== 'undefined' &&
    /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
function createInjector(context) {
    return (id, style) => addStyle(id, style);
}
let HEAD;
const styles = {};
function addStyle(id, css) {
    const group = isOldIE ? css.media || 'default' : id;
    const style = styles[group] || (styles[group] = { ids: new Set(), styles: [] });
    if (!style.ids.has(id)) {
        style.ids.add(id);
        let code = css.source;
        if (css.map) {
            // https://developer.chrome.com/devtools/docs/javascript-debugging
            // this makes source maps inside style tags work properly in Chrome
            code += '\n/*# sourceURL=' + css.map.sources[0] + ' */';
            // http://stackoverflow.com/a/26603875
            code +=
                '\n/*# sourceMappingURL=data:application/json;base64,' +
                    btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) +
                    ' */';
        }
        if (!style.element) {
            style.element = document.createElement('style');
            style.element.type = 'text/css';
            if (css.media)
                style.element.setAttribute('media', css.media);
            if (HEAD === undefined) {
                HEAD = document.head || document.getElementsByTagName('head')[0];
            }
            HEAD.appendChild(style.element);
        }
        if ('styleSheet' in style.element) {
            style.styles.push(code);
            style.element.styleSheet.cssText = style.styles
                .filter(Boolean)
                .join('\n');
        }
        else {
            const index = style.ids.size - 1;
            const textNode = document.createTextNode(code);
            const nodes = style.element.childNodes;
            if (nodes[index])
                style.element.removeChild(nodes[index]);
            if (nodes.length)
                style.element.insertBefore(textNode, nodes[index]);
            else
                style.element.appendChild(textNode);
        }
    }
}

/* script */
const __vue_script__ = script;
/* template */

var __vue_render__ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('svg', {
    staticClass: "bi",
    class: _vm.cssClasses
  }, [_c('g', {
    attrs: {
      "transform": _vm.svgTransform,
      "transform-origin": "center"
    }
  }, [_c('use', {
    attrs: {
      "xlink:href": _vm.svgSprite + "#" + _vm.icon
    }
  })])]);
};

var __vue_staticRenderFns__ = [];
/* style */

const __vue_inject_styles__ = function (inject) {
  if (!inject) return;
  inject("data-v-3ea4e60c_0", {
    source: ".bi{fill:currentColor;width:1em;height:1em;font-size:1em;margin-bottom:.125em;vertical-align:middle}.bi--variant-success{color:var(--bs-success)}.bi--variant-warning{color:var(--bs-warning)}.bi--variant-danger{color:var(--bs-danger)}.bi--variant-info{color:var(--bs-info)}.bi--variant-primary{color:var(--bs-primary)}.bi--variant-secondary{color:var(--bs-secondary)}.bi--variant-dark{color:var(--bs-dark)}.bi--variant-light{color:var(--bs-light)}.bi--size-sm{font-size:.75em}.bi--size-md{font-size:1.25rem}.bi--size-lg{font-size:1.33333333rem}.bi--size-2x{font-size:2rem}.bi--size-3x{font-size:3rem}.bi--size-4x{font-size:4rem}.bi--size-5x{font-size:5rem}.bi--animation-cylon{animation:bi-animation-cylon .75s ease-in-out infinite alternate}.bi--animation-cylon-vertical{animation:bi-animation-cylon-vertical .75s ease-in-out infinite alternate}.bi--animation-fade{animation:bi-animation-fade .75s ease-in-out infinite alternate}.bi--animation-spin{animation:bi-animation-spin 2s linear infinite normal}.bi--animation-spin-reverse{animation:bi-animation-spin 2s linear infinite reverse}.bi--animation-spin-pulse{animation:bi-animation-spin 1s steps(8) infinite normal}.bi--animation-spin-reverse-pulse{animation:bi-animation-spin 1s steps(8) infinite reverse}.bi--animation-throb{animation:bi-animation-throb .75s ease-in-out infinite alternate}@keyframes bi-animation-cylon{0%{transform:translateX(-25%)}100%{transform:translateX(25%)}}@keyframes bi-animation-cylon-vertical{0%{transform:translateY(25%)}100%{transform:translateY(-25%)}}@keyframes bi-animation-fade{0%{opacity:.1}100%{opacity:1}}@keyframes bi-animation-spin{0%{transform:rotate(0)}100%{transform:rotate(359deg)}}@keyframes bi-animation-throb{0%{opacity:.5;transform:scale(.5)}100%{opacity:1;transform:scale(1)}}",
    map: undefined,
    media: undefined
  });
};
/* scoped */


const __vue_scope_id__ = undefined;
/* module identifier */

const __vue_module_identifier__ = undefined;
/* functional template */

const __vue_is_functional_template__ = false;
/* style inject SSR */

/* style inject shadow dom */

const __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, createInjector, undefined, undefined);

var component = __vue_component__;

// Import vue component
// IIFE injects install function into component, allowing component
// to be registered via Vue.use() as well as Vue.component().

var entry_esm = /* #__PURE__ */(() => {
  // Get component instance
  const installable = component; // Attach install function executed by Vue.use()

  installable.install = Vue => {
    Vue.component('BootstrapIcon', installable);
  };

  return installable;
})(); // It's possible to expose named exports when writing components that can
// also be used as directives, etc. - eg. import { RollupDemoDirective } from 'rollup-demo';
// export const RollupDemoDirective = directive;

export { entry_esm as default };
